<?php
use Nette\Utils\Strings,
	Nette\Image;

/**
 * Homepage presenter.
 */
class HomepagePresenter extends BasePresenter
{

	private $articlesRepository;
	private $regexp;


	protected function startup()
	{

		// Require login for accessing the pages
		parent::startup();
		$this->articlesRepository = $this->context->articlesRepository;
		if (!$this->getUser()->isLoggedIn()) {
			$this->redirect('Sign:in');
		}
	}

	public function renderArticle($id)
	{


		if (empty($id)){
			$this->redirect('default');
		}

		$article = $this->articlesRepository->findArticle($id)->fetch();

		$dom = $this->context->phpQuery;
		$dom = $dom->newDocument($article->body);
		$images = pq('img');

		foreach ($images as $image)
		{
			$imageSelector = pq($image);
			$imageUrl = $this->context->httpRequest->url->baseUrl . $this->context->parameters['images']['folder'] . $imageSelector->attr('src');
			$imageSelector->attr('src', $imageUrl);
			$imageSelector->attr('alt', 'image_alt');
		}
		$article->body = $dom->htmlOuter();
		$this->template->imageFolder = $this->context->parameters['images']['folder'];
		$this->template->article = $article;
		$this->template->category = $article->category;
		$this->template->leftMenu = $this->articlesRepository->findCategory( $article->category,9,0);
	}


	public function renderCategories($id)
	{

		if (empty($id)){
			$this->redirect('default');
		}

		$paginator = $this['paginator']->getPaginator();
		
		$articles = $this->createPreview($this->articlesRepository->findCategory($id, $paginator->itemsPerPage, $paginator->offset ));

		$this->template->articles = $articles;
		$this->template->category = $id;
		$this->template->leftMenu = $this->articlesRepository->findCategory($id,9,0);
	}

	public function renderDefault()
	{

		$paginator = $this['paginator']->getPaginator();

		$articles = $this->createPreview( $this->articlesRepository->findAllLimit( $paginator->itemsPerPage, $paginator->offset ));

		$this->template->articles = $articles;
		$this->template->category = "Panorama";
		$this->template->leftMenu = $this->articlesRepository->findAllLimit(9,0);

	}

	protected function createComponentPaginator()
	{
		$visualPaginator = new VisualPaginatorControl();
		$visualPaginator->paginator->itemsPerPage = $this->context->parameters['page']['articlePerPage'];
		return $visualPaginator;
	}

	protected function createComponentSlideShow()
	{
		return new SlideShowControl($this->articlesRepository->findAllLimit(10,0));
	}

	protected function createComponentLikeButton()
	{
		$fb = $this->context->createFbToolsLikeButton();
		$fb->setAutoUrl(true);
		return $fb;
	}

	public function createComponentFbComments()
	{
		$com = new FbTools\Comments();
		$com->setAutoUrl(true);
		$com->setWidth(652);
		return $com;
	}

	public function createPreview($selection)
	{

		$articles = array();

		foreach ($selection as $article)
		{
			$articles[] = array (
				'headings' => Strings::split($article->title,'~:\s~'), 
				'id' => $article->id,
				'teaser' => $article->teaser,
				'imageTag' => "<img src=" . $this->context->httpRequest->url->baseUrl . $this->context->parameters['images']['folder'] . $article->images . " alt='" . $article->title . "'/>",
			);
		}
		return $articles;
	}

}
